@@ -22,8 +22,6 @@ from glashammer.utils.templating import create_template_environment
 from glashammer.utils import local, local_manager, EventManager, emit_event, \
     url_for, sibpath, Request
 
-from glashammer.utils.log import debug, warning
-
 
 
 def default_setup_func(app):
@@ -84,6 +82,7 @@ class GlashammerApplication(object):
         url_map=None, view_map=None,
         template_searchpaths=None, template_filters=None, template_globals=None,
         template_tests=None,
+        template_env_kw=None,
         ):
         # just for playing in the shell
         local.application = self
@@ -160,10 +159,10 @@ class GlashammerApplication(object):
         setup_func(self)
 
         # run the additional setup funcions
-        for setup_func, args in self._osetup_funcs:
-            setup_func(self, *args)
+        for setup_func, args, kw in self._osetup_funcs:
+            setup_func(self, *args, **kw)
 
-        del self._setup_funcs
+        del self._osetup_funcs
 
         emit_event('app-start', self)
 
@@ -192,6 +191,7 @@ class GlashammerApplication(object):
             globals=self._template_globals,
             filters=self._template_filters,
             tests=self._template_tests,
+            env_kw=template_env_kw,
         )
 
         del self._template_searchpaths
@@ -229,7 +229,7 @@ class GlashammerApplication(object):
         try:
             endpoint, values = adapter.match()
             request.endpoint = endpoint
-            request.values = values
+            request.endpoint_values = values
             emit_event('request-end', request)
             response = self.get_view(request, endpoint, values)
         except HTTPException, e:
@@ -263,7 +263,7 @@ class GlashammerApplication(object):
         if self.finalized:
             raise RuntimeError('You cannot do this. The application has been finalized.')
 
-    def add_setup(self, setup_func, *args):
+    def add_setup(self, setup_func, *args, **kw):
         """Add a setup callable to be called on startup by the application.
 
         `setup_func`
@@ -272,6 +272,9 @@ class GlashammerApplication(object):
         `*args`
             Arguments that will be passed to the setup function
 
+        `**kw`
+            Keyword arguments that will be passed to the setup function
+
         This method is used to add pluggable capability to the application.
         For example, plugin A can load plugin B by importing and adding it's
         setup func like so::
@@ -288,9 +291,9 @@ class GlashammerApplication(object):
         """
         self._ensure_not_finalized()
 
-        vals = (setup_func, args)
-        if vals not in self._setup_funcs:
-            self._setup_funcs.add(vals)
+        vals = (setup_func, args, kw)
+
+        if vals not in self._osetup_funcs:
             self._osetup_funcs.append(vals)
 
     def add_data_func(self, data_func):
@@ -303,13 +306,13 @@ class GlashammerApplication(object):
             self._data_funcs.add(data_func)
             self._odata_funcs.append(data_func)
 
-    def add_bundle(self, bundle):
+    def add_bundle(self, bundle, *args, **kw):
         """
         Add a bundle (a module or other thing with a setup_app callable
         """
         self._ensure_not_finalized()
 
-        self.add_setup(bundle.setup_app)
+        self.add_setup(bundle.setup_app, *args, **kw)
 
     def add_url(self, url, endpoint, view=None, **kw):
         """
@@ -412,7 +415,7 @@ class GlashammerApplication(object):
         self._ensure_not_finalized()
 
         self._template_filters[name] = f
-    
+
     def add_template_test(self, name, f):
         """
         Add a template filter.
@@ -442,9 +445,18 @@ class GlashammerApplication(object):
         """
         self._ensure_not_finalized()
 
-        self._shared_exports['/_shared/' + name] = path
-        self.add_url('/_shared/%s/<string:filename>' % name,
-                     endpoint='shared/' + name, build_only=True)
+        #Allow empty name
+        if name == '':
+            sep = ''
+        else:
+            sep = '/'
+
+        url = sep.join(['/_shared', name])
+        ep = sep.join(['shared', name])
+
+        self._shared_exports[url] = path
+        self.add_url('%s/<string:filename>' % url,
+                     endpoint=ep, build_only=True)
 
     def add_middleware(self, middleware_factory, *args, **kwargs):
         """
