@@ -6,7 +6,9 @@
     :copyright: 2007-2008 by Armin Ronacher, Ali Afshar
     :license: MIT
 """
-from glashammer.utils.local import url_for
+import math
+
+from glashammer.utils.local import url_for, local
 
 
 
@@ -26,8 +28,8 @@ class Pagination(object):
                  active='<strong>%(page)d</strong>',
                  commata='<span class="commata">,\n</span>',
                  ellipsis=u'<span class="ellipsis">...\n</span>',
-                 threshold=3, prev_link=False,
-                 next_link=False, gray_prev_link=True, gray_next_link=True):
+                 threshold=3, prev_link=True,
+                 next_link=True, gray_prev_link=True, gray_next_link=True):
         was_ellipsis = False
         result = []
         prev = None
@@ -75,8 +77,10 @@ class Pagination(object):
 
 class NavigationItem(object):
     """An item that contains navigation information"""
-    def __init__(self, title, endpoint, rule_args={}, children=[],
+    def __init__(self, title, endpoint, rule_args={}, children=None,
                  nolink=False):
+        if children is None:
+            children = []
         self.title = title
         self.endpoint = endpoint
         self.children = children
@@ -98,6 +102,6 @@ def flash(msg, type='info'):
     assert type in ('info', 'add', 'remove', 'error', 'ok', 'configure')
     if type == 'error':
         msg = (u'<strong>%s:</strong> ' % _('Error')) + msg
-    local.request.session.setdefault('admin/flashed_messages', []).\
+    local.session.setdefault('admin/flashed_messages', []).\
             append((type, msg))
 
