@@ -1,5 +1,6 @@
 
-import os, shutil
+import os, shutil, urlparse
+
 from datetime import datetime, date, time
 
 from nose.tools import assert_raises
@@ -11,6 +12,8 @@ from glashammer.utils import render_response, Response, local, \
     render_template, sibpath, get_request, get_app, url_for, \
     gen_pwhash, check_pwhash, Configuration
 
+from glashammer.utils.http import redirect, redirect_to
+
 from glashammer.utils.json import json_view, JsonRestService
 
 from glashammer.bundles import i18n
@@ -954,104 +957,6 @@ class TestPagination(object):
 """.strip()
 
 
-#sqla
-
-from glashammer.bundles.sqladb import setup_sqladb, db, metadata, \
-    JsonSqlaRestService
-
-class TestSQLA(object):
-
-    def setup(self):
-        if os.path.exists('test_output/gh.sqlite'):
-            os.unlink('test_output/gh.sqlite')
-
-
-        metadata.drop_all()
-
-
-        # The SQLA tables
-        notes = db.Table('notes', metadata,
-            db.Column('id', db.Integer, primary_key=True),
-            db.Column('title', db.Text),
-            db.Column('note', db.Text),
-            db.Column('importance', db.Text),
-            useexisting=True,
-        )
-
-        # The ORM mapped class
-        class Note(object):
-            """ Represents a note """
-
-        self.Note = Note
-
-        # Make a mapper which gives you the objects manager
-        db.mapper(Note, notes)
-
-
-        class NotesService(JsonSqlaRestService):
-
-            def get_table(self):
-                return Note
-
-        def setup_db(app):
-            #metadata.create_all(app.sqla_db_engine)
-            #print metadata.tables
-            #print dir(notes)
-            notes.create(app.sqla_db_engine)
-
-        def setup_app(app):
-            app.add_setup(setup_sqladb)
-            app.add_data_func(setup_db)
-            app.add_url('/notes', 'notes/svc', view=NotesService())
-
-        self.app = make_app(setup_app, 'test_output')
-        self.c = Client(self.app)
-
-    def test_engine(self):
-        assert get_app().sqla_db_engine
-
-    def test_objects(self):
-        assert self.Note.objects.count() == 0
-        for t in 'abcdef':
-            n = self.Note()
-            n.title = n.note = n.importance = t
-        db.commit()
-        assert self.Note.objects.count() == 6
-
-    def test_rest_get(self):
-        for t in 'abcdef':
-            n = self.Note()
-            n.title = n.note = n.importance = t
-        db.commit()
-        iter, status, header = self.c.open('/notes')
-        resp = loads(''.join(iter))
-        res = resp['results']
-        assert resp['total'] == 6
-        for i, l in enumerate('abcdef'):
-            assert res[i]['title'] == l
-            assert res[i]['note'] == l
-            assert res[i]['importance'] == l
-            assert res[i]['id'] == (i + 1)
-
-    def test_rest_post(self):
-        for t in 'abcdef':
-            n = self.Note()
-            n.title = n.note = n.importance = t
-        db.commit()
-        iter, status, header = self.c.post('/notes',
-            data={
-                'title': 'g',
-                'note': 'g',
-                'importance':'g'
-            }
-        )
-        resp = loads(''.join(iter))
-        res = resp['results']
-        assert resp['total'] == 1
-        assert resp['results'][0]['title'] == 'g'
-        assert resp['results'][0]['note'] == 'g'
-        assert resp['results'][0]['importance'] == 'g'
-        assert resp['results'][0]['id'] > 0
 
 
 # openid
@@ -1071,6 +976,48 @@ def test_openid():
     assert '302' in status
 
 
+# http redirects
+
+def _boo_view(req):
+    return redirect('/home')
+
+def _foo_view(req):
+    return redirect_to('test/home')
+
+def _home_view(req):
+    return Response('hello')
+
+def _setup_redirect_app(app):
+    app.add_url('/home', 'test/home', _home_view)
+    app.add_url('/foo', 'test/foo', _foo_view)
+    app.add_url('/boo', 'test/boo', _boo_view)
+
+
+
+def _test_redirect_helper(getpath):
+    app = make_app(_setup_redirect_app, 'test_output')
+
+    c = Client(app)
+    appiter, status, headers = c.open('/foo')
+
+    s = list(appiter)[0]
+
+    location = dict(headers).get('Location')
+
+    assert location
+
+    path = urlparse.urlparse(location)[2]
+
+    assert path == '/home'
+
+def test_redirect():
+    _test_redirect_helper('/foo')
+
+def test_redirect_to():
+    _test_redirect_helper('/boo')
+
+
+
 # functional tests for examples
 
 from glashammer.utils.system import load_app_from_path
